@@ -62,11 +62,11 @@ App::Dochazka::REST::Dispatch::Employee - path dispatch
 
 =head1 VERSION
 
-Version 0.109
+Version 0.114
 
 =cut
 
-our $VERSION = '0.109';
+our $VERSION = '0.114';
 
 
 
@@ -90,7 +90,8 @@ Adds employee-related routes to C<$router_get> (router for GET requests).
 
 sub _init_get {
 
-    my $router_get = __PACKAGE__->SUPER::_router_get;
+    my $router_get = __PACKAGE__->SUPER::router( 'GET' );
+    die "Bad Path::Router object" unless $router_get->isa( 'Path::Router' );
 
     $router_get->add_route( 'employee',
         target => \&_get_default,
@@ -131,7 +132,7 @@ Adds employee-related routes to C<$router_post> (router for POST requests).
 =cut
 
 sub _init_post {
-    my $router_post = __PACKAGE__->SUPER::_router_post;
+    my $router_post = __PACKAGE__->SUPER::router( 'POST' );
     return "Employee POST router initialization complete";   
 }
 
