@@ -54,11 +54,11 @@ App::Dochazka::REST::Model::Privhistory - privilege history functions
 
 =head1 VERSION
 
-Version 0.109
+Version 0.114
 
 =cut
 
-our $VERSION = '0.109';
+our $VERSION = '0.114';
 
 
 
@@ -366,26 +366,27 @@ sub delete {
 
 =head2 get_privhistory
 
-Given a database handle, an EID, and an optional tsrange, return the
-history of privilege level changes for that employee over the given
-tsrange, or the entire history if no tsrange is supplied. Returns a
-status object where the payload is a reference to an array of C<privhistory>
-objects. If nothing is found, the array will be empty. If there is 
-a DBI error, the payload will be undefined.
+Given an EID and an optional tsrange, return the history of privilege level
+changes for that employee over the given tsrange, or the entire history if no
+tsrange is supplied. Returns a status object where the payload is a reference
+to an array of C<privhistory> objects. If nothing is found, the array will be
+empty. If there is a DBI error, the payload will be undefined.
 
 =cut
 
 sub get_privhistory {
-    my ( $dbh, $eid, $tsr ) = @_;
+    my ( $eid, $tsr ) = @_;
+    my $dbh = __PACKAGE__->SUPER::dbh;
+    die "Bad database handle" unless $dbh->ping;
     $tsr = '[,)' if not $tsr;
     my $status;
+    my $counter = 0;
     my $result = [];
-     
-    my $sth = $dbh->prepare( $site->SQL_PRIVHISTORY_SELECT_RANGE );
+
     $dbh->{RaiseError} = 1;
     try {
+        my $sth = $dbh->prepare( $site->SQL_PRIVHISTORY_SELECT_RANGE );
         $sth->execute( $eid, $tsr );
-        my $counter = 0;
         while( defined( my $tmpres = $sth->fetchrow_hashref() ) ) {
             $counter += 1;
             my $ph = __PACKAGE__->spawn(
@@ -394,16 +395,19 @@ sub get_privhistory {
             $ph->reset( %$tmpres );
             push @$result, $ph;
         }
-        if ( $counter > 0 ) {
-            $status = $CELL->status_ok( "$counter privhistory records found", payload => $result );
-        } else {
-            $status = $CELL->status_warn( "$counter privhistory records found", payload => $result );
-        }
     } catch {
-        $status => $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ], payload => undef ); 
+        $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $_ ], payload => undef ); 
     };
     $dbh->{RaiseError} = 0;
-
+    return $status if defined $status;
+    if ( $counter > 0 ) {
+        $status = $CELL->status_ok( 'DISPATCH_RECORDS_FOUND', args => 
+            [ $counter ], payload => $result, count => $counter );
+    } else {
+        $status = $CELL->status_warn( 'DISPATCH_PRIVHISTORY_EMPTY', 
+            args => [ 'FIXME' ], payload => $result, count => $counter );
+    }
+    $dbh->{RaiseError} = 0;
     return $status;
 }
   
